@@ -73,7 +73,6 @@ void testPlatform::setUp()
     string programDirname = getCppunitTopDirectory();
     string writeDirectory = getWritableDirectory();
 
-    string xmlFile = programDirname + getXmlFile();
     string testInput = programDirname + getTestDirectory() + "/testInput.xml";
     if(!fileExists(testInput))
         testInput = getTestDirectory() + "/testInput.xml"; 
@@ -97,9 +96,6 @@ void testPlatform::setUp()
     // Smi output file.
     string smiOutput = writeDirectory + "/smi-output.dat";
 
-    // set up XML factory. from here on, we can just say SmbiosFactory.
-    smbios::SmbiosXmlFactory::getFactory();
-
     // normal users of the smbios classes need not
     // set the four parameters below. They should all be set inside the factory
     // properly by default. We override stuff here to have
@@ -118,9 +114,6 @@ void testPlatform::setUp()
     smi::SmiFactory::getFactory()->setParameter("smiFile", smiOutput);
     smi::SmiFactory::getFactory()->setMode( smi::SmiFactory::UnitTestMode );
 
-    // The parameter below will normally need to be set by the client code.
-    smbios::SmbiosFactory::getFactory()->setParameter("xmlFile", xmlFile);
-
     doc = 0;
     parser = 0;
     InitXML();
@@ -128,11 +121,6 @@ void testPlatform::setUp()
     compatXmlReadFile(parser, doc, testInput.c_str());
 }
 
-void testPlatform::resetFactoryToBuiltinXml()
-{
-    smbios::SmbiosFactory::getFactory()->setParameter("xmlFile", "");
-}
-
 void testPlatform::tearDown()
 {
     // the factory is static. If we do not reset the factory, the next
@@ -194,9 +182,9 @@ testPlatform::testCmosChecksum ()
 
     smbios::TokenTableFactory *ttFactory;
     ttFactory = smbios::TokenTableFactory::getFactory() ;
-    smbios::ITokenTable *tokenTable = ttFactory->getSingleton();
+    const smbios::ITokenTable *tokenTable = ttFactory->getSingleton();
 
-    smbios::ITokenTable::iterator token = tokenTable->begin();
+    smbios::ITokenTable::const_iterator token = tokenTable->begin();
     while( token != tokenTable->end() )
     {
         (void) *token;
@@ -416,12 +404,6 @@ testPlatform::testSystemInfo()
     STD_TEST_END("");
 }
 
-void testPlatform::testSystemInfo_builtinXml ()
-{
-    resetFactoryToBuiltinXml();
-    testPlatform::testSystemInfo();
-}
-
 
 // testInput.xml tests
 string testPlatform::getTestInputString( string toFind, string section )
@@ -669,10 +651,10 @@ void testPlatform::testVariousAccessors()
 
     // table should not be deleted when we are finished. It is managed by the
     // factory. Factory will delete it for us when ->reset() is called.
-    smbios::ISmbiosTable *table =
+    const smbios::ISmbiosTable *table =
         smbios::SmbiosFactory::getFactory()->getSingleton();
 
-    smbios::ISmbiosTable::iterator item = (*table)["BIOS Information"] ;
+    smbios::ISmbiosTable::const_iterator item = (*table)[smbios::BIOS_Information] ;
 
     string vendorStr="";
     string versionStr="";
@@ -803,10 +785,10 @@ testPlatform::testOutOfBounds()
 {
     STD_TEST_START_CHECKSKIP(getTestName().c_str() << "  ");
 
-    smbios::ISmbiosTable *table =
+    const smbios::ISmbiosTable *table =
         smbios::SmbiosFactory::getFactory()->getSingleton();
 
-    smbios::ISmbiosTable::iterator item = (*table)["BIOS Information"] ;
+    smbios::ISmbiosTable::const_iterator item = (*table)[smbios::BIOS_Information] ;
 
     // access string '0' should always throw. (string offset start at 1, per
     // spec)
@@ -863,11 +845,11 @@ testPlatform::testConstructionOffset1()
     }
 
     smbios::SmbiosFactory::getFactory()->setParameter("offset", offset);
-    smbios::ISmbiosTable *table =
+    const smbios::ISmbiosTable *table =
         smbios::SmbiosFactory::getFactory()->getSingleton();
 
     int tableEntriesCounted = 0;
-    smbios::ISmbiosTable::iterator item = table->begin();
+    smbios::ISmbiosTable::const_iterator item = table->begin();
     while( item != table->end() )
     {
         tableEntriesCounted++;
@@ -912,22 +894,22 @@ testPlatform::testConstructionOffset2()
     //  DO NOT USE ->getSingleton() here... we use ->makeNew() on purpose.
     //  This is an internal test and the parameters of this test mean we should _not_ use a singleton.
     factory->setParameter("offset", 1);
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
 
     factory->setParameter("offset", 1000);
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
 
     factory->setParameter("offset", 0xFFFFFUL ); // F_BLOCK_END (private definition)
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
 
     factory->setParameter("offset", 0xFFFFFUL - 1); // F_BLOCK_END (private definition)
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable>p(factory->makeNew()), smbios::IException );
 
     smbios::SmbiosFactory::getFactory()->setParameter("offset", offset + 1);
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable> table( factory->makeNew() ), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable> table( factory->makeNew() ), smbios::IException );
 
     smbios::SmbiosFactory::getFactory()->setParameter("offset", offset - 1);
-    ASSERT_THROWS( auto_ptr<smbios::ISmbiosTable> table( factory->makeNew() ), smbios::IException );
+    ASSERT_THROWS( auto_ptr<const smbios::ISmbiosTable> table( factory->makeNew() ), smbios::IException );
 
     // should not be able to use no-argument constructor...
     // UNCOMMENT TO CHECK.
